pub struct SkippableSetting {
pub kind: Option<String>,
pub skip_offset: Option<VideoOffset>,
pub skippable: Option<bool>,
pub progress_offset: Option<VideoOffset>,
}Expand description
Skippable Settings
This type is not used in any activity, and only used as part of another schema.
Fields
kind: Option<String>Identifies what kind of resource this is. Value: the fixed string “dfareporting#skippableSetting”.
skip_offset: Option<VideoOffset>Amount of time to play videos served to this placement before the skip button should appear. Applicable when skippable is true.
skippable: Option<bool>Whether the user can skip creatives served to this placement.
progress_offset: Option<VideoOffset>Amount of time to play videos served to this placement before counting a view. Applicable when skippable is true.